@@ -11,12 +11,12 @@ export DISPLAY=:0.0
 TMPFILE=/tmp/.launcher/resume-event
 
 case "$1" in 
-	suspend)
+	suspend|hibernate)
 		rm -rf $TMPFILE
     echo "Removed resume-notify file"
 
 	;;
-	resume)
+	resume|thaw)
  	  touch $TMPFILE
     echo "Created resume-notify file"
 	;;
